import fetch from "node-fetch";
import { InjectionResult, SaveResult } from "./constants.js";
import { logger } from "./logger.js";
import { getRuntimeConfig } from "./runtimeConfig.js";
import { formatAsList } from "./utils.js";
export let pushNotifier;
var Event;
(function (Event) {
    Event["RESULTS"] = "RESULTS";
})(Event || (Event = {}));
export class PushNotifier {
    constructor(url) {
        this.url = url;
    }
    notify({ title = "cross-seed", body, ...rest }) {
        if (this.url) {
            fetch(this.url, {
                method: "POST",
                headers: { "Content-Type": "application/json" },
                body: JSON.stringify({ title, body, ...rest }),
            }).catch(() => {
                logger.error({ message: "Failed to send push notification" });
            });
        }
    }
}
export function sendResultsNotification(searchee, results, source) {
    const name = searchee.name;
    const notableSuccesses = results.filter(([, , actionResult]) => actionResult === InjectionResult.SUCCESS ||
        actionResult === SaveResult.SAVED);
    const failures = results.filter(([, , actionResult]) => actionResult === InjectionResult.FAILURE);
    if (notableSuccesses.length) {
        const numTrackers = notableSuccesses.length;
        const infoHashes = notableSuccesses.map(([assessment]) => assessment.metafile.infoHash);
        const trackers = notableSuccesses.map(([, tracker]) => tracker);
        const trackersListStr = formatAsList(trackers);
        const performedAction = notableSuccesses[0][2] === InjectionResult.SUCCESS
            ? "Injected"
            : "Saved";
        pushNotifier.notify({
            body: `${source}: ${performedAction} ${name} from ${numTrackers} trackers: ${trackersListStr}`,
            extra: {
                event: Event.RESULTS,
                name,
                infoHashes,
                trackers,
                source,
                result: notableSuccesses[0][2],
            },
        });
    }
    if (failures.length) {
        const numTrackers = failures.length;
        const infoHashes = failures.map(([assessment]) => assessment.metafile.infoHash);
        const trackers = failures.map(([, tracker]) => tracker);
        const trackersListStr = formatAsList(trackers);
        pushNotifier.notify({
            body: `Failed to inject ${name} from ${numTrackers} trackers: ${trackersListStr}`,
            extra: {
                event: Event.RESULTS,
                name,
                infoHashes,
                trackers,
                source,
                result: failures[0][2],
            },
        });
    }
}
export function initializePushNotifier() {
    const { notificationWebhookUrl } = getRuntimeConfig();
    pushNotifier = new PushNotifier(notificationWebhookUrl);
}
export function sendTestNotification() {
    pushNotifier.notify({ body: "Test", extra: { event: "TEST" } });
    logger.info("Sent test notification");
}
//# sourceMappingURL=pushNotifier.js.map