import { readdirSync, statSync } from "fs";
import { basename, join, relative } from "path";
import { logger } from "./logger.js";
import { resultOf, resultOfErr } from "./Result.js";
import { parseTorrentFromFilename } from "./torrent.js";
function getFileNamesFromRootRec(root, isDirHint) {
    const isDir = isDirHint !== undefined ? isDirHint : statSync(root).isDirectory();
    if (isDir) {
        return readdirSync(root, { withFileTypes: true }).flatMap((dirent) => getFileNamesFromRootRec(join(root, dirent.name), dirent.isDirectory()));
    }
    else {
        return [root];
    }
}
function getFilesFromDataRoot(rootPath) {
    const parentDir = join(rootPath, "..");
    return getFileNamesFromRootRec(rootPath).map((file) => ({
        path: relative(parentDir, file),
        name: basename(file),
        length: statSync(file).size,
    }));
}
export function createSearcheeFromMetafile(meta) {
    return {
        files: meta.files,
        infoHash: meta.infoHash,
        name: meta.name,
        length: meta.length,
    };
}
export async function createSearcheeFromTorrentFile(filepath) {
    try {
        const meta = await parseTorrentFromFilename(filepath);
        return resultOf(createSearcheeFromMetafile(meta));
    }
    catch (e) {
        logger.error(`Failed to parse ${basename(filepath)}`);
        logger.debug(e);
        return resultOfErr(e);
    }
}
export async function createSearcheeFromPath(filepath) {
    const totalLength = getFilesFromDataRoot(filepath).reduce((runningTotal, file) => runningTotal + file.length, 0);
    return resultOf({
        files: getFilesFromDataRoot(filepath),
        path: filepath,
        name: basename(filepath),
        length: totalLength,
    });
}
//# sourceMappingURL=searchee.js.map